Home and Gardening Forums & Blogs - Garden Stew

First visit to GardenStew? Learn more | Already a member? -> Sign in Not a member yet? -> Register
Welcome to GardenStew, a friendly community for gardeners and home owners featuring active forums, blogs, plant database, simple photo upload and more! Online since 2004, we love to share! Register for free right now or learn more. Here is our list of forums. Please join our insightful discussions.
## Community
|  | Forum Name | Topics | Posts
|  | Welcome to GardenStew Introduce yourself to the community and welcome new members. A great place to write your first post. | 1493 | 18290
|  | The Village Square Friendly chat about topics not covered in the other forums. Gather round, gather round! Sub-forums: Birthdays & Anniversaries | In Memory Of | 5148 | 69219
|  | Member's Gallery A place to post photos of your gardens, flowers, pets, adventures, anything! Sub-forums: Garden Visits and Flower Shows | 6906 | 69371
|  | How To: Various How-To tutorials to help you. | 4 | 4
## Growing Specifics
|  | Forum Name | Topics | Posts
|  | Flower Gardening General flower gardening discussion. Flower care and tips, growing conditions, propagation, transplanting and more. Sub-forums: Daylily | 1925 | 15352
|  | Trees, Shrubs and Roses General trees, shrubs and roses discussion. Care and tips, growing conditions, propagation, transplanting and more. Sub-forums: Hydrangea | 834 | 5053
|  | Fruit and Veg Gardening General fruit and vegetable gardening discussion. Tips for sustainable living, growing in allotments, containers, greenhouses and more. | 1906 | 17372
|  | Herb Gardening General herb gardening discussion. Basil, chives, lavender, mint, sage, thyme and more. | 290 | 2072
|  | Houseplants General houseplant discussion. Care and tips, growing conditions, watering, propagation and more. | 537 | 4403
|  | Lawn Care General lawn care discussion. Seeding, maintenance, common problems, machinery and more. | 174 | 1101
|  | Water Gardening General water gardening discussion. Care of water plants, ponds, waterfalls and other water garden features. | 169 | 1439
## Plant Central
|  | Forum Name | Topics | Posts
|  | Plant ID Our members help identify your mystery plants. Be as descriptive as possible. | 1579 | 11606
|  | Plant and Seed Exchange Swap seeds and plants with other members of the site. Be aware that restrictions may apply depending on where you live. Read the topic marked "[IMPORTANT] International seed swaps" | 535 | 2113
|  | Seed Starting / Propagation Tips on how to get your seeds off to a healthy start. Container types, proper storage, lighting, moisture, temperatures, soil types. | 167 | 1427
|  | Plant Pests, Diseases and Weeds General pests, diseases and weeds discussion. Organic and inorganic treatments, prevention and control. | 389 | 2658
## Yet More Gardening
|  | Forum Name | Topics | Posts
|  | Garden Design General garden design discussion. Planning, layout, structures, colours, garden styles and more. | 305 | 2702
|  | Wildlife in the Garden General wildlife discussion. Attracting wildlife, preventing wildlife damage to plants and other tips. Sub-forums: Bird | Butterfly / Moth | 1380 | 11489
|  | Gardening Other General gardening tips that do not fit into any of the other forums. Making life in the garden easier. Sub-forums: Greenhouse | Organic Gardening | 663 | 5458
## Around the Home
|  | Forum Name | Topics | Posts
|  | Hobbies and Crafts General hobbies and crafts discussion. Garden junk , painting, scrapbooking, woodwork, beekeeping and more Sub-forums: Garden Junk | Woodworking | 726 | 7903
|  | Recipes and Cooking General recipes and cooking discussion. Share recipes, methods, preparation tips, time saving ideas and more. | 581 | 4900
|  | Interior Design General interior design discussion. Furniture, flooring, wall treatment, lighting, accessories and more. Sub-forums: Choosing Colors | 497 | 3226
|  | Home Improvement, DIY and Repair General home improvement discussion. DIY, repairs, additions, renovation, safety tips and more. | 167 | 1789
|  | Computer and Internet General computer and Internet discussion. Viruses, security, applications, useful websites, hardware and more. | 235 | 1994
|  | Pets General pet discussion. Pet stories, care, training, and environments. Discuss dogs, cats, birds and more. | 533 | 6245
|  | Books General book discussion. Currently reading, recommendations, books to avoid, favourite books and more. | 62 | 607
## Site Stuff
|  | Forum Name | Topics | Posts
|  | Site Rules and Guidelines ## Before posting be sure to read the site rules and guidelines. ## | 3 | 2
|  | Suggestions / Comments / Help We constantly need your feedback to help us improve. Confused about something or would like to see something added? Let us know. | 211 | 1216
|  | Site News For all important announcements and news regarding GardenStew.com, new features, competitions etc... | 51 | 428
## Other
|  | Forum Name | Topics | Posts
|  | Featured Topics Topics of a particularily high quality are moved to the Featured Topics area. See if you can start one! We like tutorials and topics that encourage active, informative discussion. | - | -
|  | Testing Test signatures, avatar images, posting images and other posting features before "going live" on the other forums. | 83 | 331
|  | Useful Articles Useful and interesting articles from around the Web and from our members. All non-member articles are reprinted with permission. | 5 | 18
|  | Jokes and Games Have a laugh in the jokes and games forum. Jokes, posting games, fun competitions, flash games, videos and more. | 2239 | 23952
Mark all forums read |  |  | New posts |  | No new posts |  | Forum is locked
| Pic Of The Month A Pair of Blue Jays posted by Sherry8 Latest Plant Image
Uploaded to Yucca filamentosa by Jerry Sullivan Today's Calendar Events Add a Calendar Event Community Stats 18820 members 311273 forum posts 568 blogs 5185 blog entries Our newest member is fikizuro Forum RSS
back to top of page | Sponsored Links